@@ -22,12 +22,7 @@
 
 #include "databasetestdata.h"
 
-#include "musicaudiotrack.h"
-
-#include <QList>
 #include <QHash>
-#include <QString>
-#include <QUrl>
 
 class ManageMediaPlayerControlTest : public QObject, public DatabaseTestData
 {
@@ -46,20 +41,9 @@ private Q_SLOTS:
 
     void simpleInitialCase();
 
-    void addItemInModelCase();
-
-    void addItemInModelCaseV2();
-
-    void nextAndPreviousButtonAndRandomPlay();
-
-    void moveCurrentTrack();
-
-    void moveAnotherTrack();
-
-    void setCurrentTrackTest();
-
-    void setPlayListModelTest();
+    void testPlayingCase();
 
+    void testTracksCase();
 };
 
 #endif // MANAGEMEDIAPLAYERCONTROLTEST_H
