@@ -28,6 +28,12 @@ class TrackMetadataModelTests: public QObject, public DatabaseTestData
 {
     Q_OBJECT
 
+public:
+
+    explicit TrackMetadataModelTests(QObject *aParent = nullptr) : QObject(aParent)
+    {
+    }
+
 private Q_SLOTS:
 
     void initTestCase()
