@@ -37,6 +37,7 @@
 #include "elisaapplication.h"
 #include "progressindicator.h"
 #include "mediaplaylist.h"
+#include "mediaplaylistproxymodel.h"
 #include "managemediaplayercontrol.h"
 #include "manageheaderbar.h"
 #include "manageaudioplayer.h"
@@ -48,10 +49,11 @@
 #include "models/datamodel.h"
 #include "models/trackmetadatamodel.h"
 #include "models/trackcontextmetadatamodel.h"
+#include "models/editabletrackmetadatamodel.h"
 #include "models/viewsmodel.h"
 #include "models/gridviewproxymodel.h"
 #include "models/alltracksproxymodel.h"
-#include "models/singlealbumproxymodel.h"
+#include "localFileConfiguration/elisaconfigurationdialog.h"
 
 #if defined KF5FileMetaData_FOUND && KF5FileMetaData_FOUND
 #include "embeddedcoverageimageprovider.h"
@@ -69,14 +71,17 @@
 #include "mpris2/mediaplayer2player.h"
 #endif
 
-#include <QSortFilterProxyModel>
 
 #include <QAction>
 #include <QStandardPaths>
 
 #include <QQmlExtensionPlugin>
 #include <QQmlEngine>
-#include <QQmlContext>
+
+ElisaQmlTestPlugin::ElisaQmlTestPlugin(QObject *aParent)
+    : QQmlExtensionPlugin(aParent)
+{
+}
 
 void ElisaQmlTestPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
 {
@@ -111,6 +116,7 @@ void ElisaQmlTestPlugin::registerTypes(const char *uri)
 #endif
 
     qmlRegisterType<MediaPlayList>(uri, 1, 0, "MediaPlayList");
+    qmlRegisterType<MediaPlayListProxyModel>(uri, 1, 0, "MediaPlayListProxyModel");
     qmlRegisterType<ManageMediaPlayerControl>(uri, 1, 0, "ManageMediaPlayerControl");
     qmlRegisterType<ManageHeaderBar>(uri, 1, 0, "ManageHeaderBar");
     qmlRegisterType<ManageAudioPlayer>(uri, 1, 0, "ManageAudioPlayer");
@@ -120,10 +126,10 @@ void ElisaQmlTestPlugin::registerTypes(const char *uri)
     qmlRegisterType<DataModel>(uri, 1, 0, "DataModel");
     qmlRegisterType<TrackMetadataModel>(uri, 1, 0, "TrackMetadataModel");
     qmlRegisterType<TrackContextMetaDataModel>(uri, 1, 0, "TrackContextMetaDataModel");
+    qmlRegisterType<EditableTrackMetadataModel>(uri, 1, 0, "EditableTrackMetadataModel");
     qmlRegisterType<ViewsModel>(uri, 1, 0, "ViewsModel");
     qmlRegisterType<GridViewProxyModel>(uri, 1, 0, "GridViewProxyModel");
     qmlRegisterType<AllTracksProxyModel>(uri, 1, 0, "AllTracksProxyModel");
-    qmlRegisterType<SingleAlbumProxyModel>(uri, 1, 0, "SingleAlbumProxyModel");
 
 #if defined KF5KIO_FOUND && KF5KIO_FOUND
     qmlRegisterType<FileBrowserModel>(uri, 1, 0, "FileBrowserModel");
@@ -173,6 +179,7 @@ void ElisaQmlTestPlugin::registerTypes(const char *uri)
     qRegisterMetaType<TracksListener::TrackDataType>("TracksListener::TrackDataType");
     qRegisterMetaType<ViewManager::ViewsType>("ViewManager::ViewsType");
     qRegisterMetaType<ViewManager::SortOrder>("ViewManager::SortOrder");
+    qmlRegisterUncreatableType<ElisaConfigurationDialog>(uri, 1, 0, "ElisaConfigurationDialog", QStringLiteral("only one and done in c++"));
 
     qmlRegisterUncreatableType<ElisaApplication>(uri, 1, 0, "ElisaApplication", QStringLiteral("only one and done in c++"));
     qmlRegisterUncreatableMetaObject(ElisaUtils::staticMetaObject, uri, 1, 0, "ElisaUtils", QStringLiteral("Namespace ElisaUtils"));
