@@ -410,14 +410,14 @@ void ManageAudioPlayer::setPlayerPosition(qint64 playerPosition)
 
     mPlayerPosition = playerPosition;
     Q_EMIT playerPositionChanged();
-    QTimer::singleShot(0, [this]() {Q_EMIT playControlPositionChanged();});
+    QTimer::singleShot(0, this, [this]() {Q_EMIT playControlPositionChanged();});
 }
 
-void ManageAudioPlayer::setCurrentPlayingForRadios(QString title, QString nowPlaying)
+void ManageAudioPlayer::setCurrentPlayingForRadios(const QString &title, const QString &nowPlaying)
 {
     if (mPlayListModel && mCurrentTrack.isValid()) {
-        Q_EMIT currentPlayingForRadiosChanged(title, MediaPlayList::TitleRole);
-        Q_EMIT currentPlayingForRadiosChanged(nowPlaying, MediaPlayList::ArtistRole);
+        Q_EMIT updateData(mCurrentTrack, title, MediaPlayList::TitleRole);
+        Q_EMIT updateData(mCurrentTrack, nowPlaying, MediaPlayList::ArtistRole);
     }
 }
 
@@ -532,22 +532,22 @@ void ManageAudioPlayer::notifyPlayerSourceProperty()
 
 void ManageAudioPlayer::triggerPlay()
 {
-    QTimer::singleShot(0, [this]() {Q_EMIT playerPlay();});
+    QTimer::singleShot(0, this, [this]() {Q_EMIT playerPlay();});
 }
 
 void ManageAudioPlayer::triggerPause()
 {
-    QTimer::singleShot(0, [this]() {Q_EMIT playerPause();});
+    QTimer::singleShot(0, this, [this]() {Q_EMIT playerPause();});
 }
 
 void ManageAudioPlayer::triggerStop()
 {
-    QTimer::singleShot(0, [this]() {Q_EMIT playerStop();});
+    QTimer::singleShot(0, this, [this]() {Q_EMIT playerStop();});
 }
 
 void ManageAudioPlayer::triggerSkipNextTrack()
 {
-    QTimer::singleShot(0, [this]() {Q_EMIT skipNextTrack();});
+    QTimer::singleShot(0, this, [this]() {Q_EMIT skipNextTrack();});
 }
 
 void ManageAudioPlayer::restorePreviousState()
