@@ -46,18 +46,12 @@
 #include <KI18n/KLocalizedString>
 
 #include <QThread>
-#include <QMutex>
 #include <QStandardPaths>
 #include <QDir>
 #include <QCoreApplication>
-#include <QList>
-#include <QScopedPointer>
-#include <QPointer>
 #include <QFileSystemWatcher>
 #include <QAction>
 
-#include <QDebug>
-
 #include <list>
 
 class MusicListenersManagerPrivate
@@ -90,6 +84,8 @@ public:
 
     QFileSystemWatcher mConfigFileWatcher;
 
+    QStringList mPreviousRootPathValue;
+
     ElisaApplication *mElisaApplication = nullptr;
 
     int mImportedTracksCount = 0;
@@ -226,6 +222,9 @@ auto MusicListenersManager::initializeRootPath()
     }
 
     Elisa::ElisaConfiguration::setRootPath(initialRootPath);
+    Elisa::ElisaConfiguration::setShowProgressOnTaskBar(true);
+    Elisa::ElisaConfiguration::setShowSystemTrayIcon(false);
+    Elisa::ElisaConfiguration::setForceUsageOfFastFileSearch(true);
     Elisa::ElisaConfiguration::self()->save();
 
     return initialRootPath;
@@ -327,9 +326,28 @@ void MusicListenersManager::configChanged()
     currentConfiguration->load();
     currentConfiguration->read();
 
+    bool configurationHasChanged = false;
+#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+    if (d->mBalooIndexerAvailable && d->mBalooIndexerActive && d->mBalooListener.canHandleRootPaths() && !currentConfiguration->forceUsageOfFastFileSearch()) {
+        configurationHasChanged = true;
+    } else if (d->mBalooIndexerAvailable && !d->mBalooIndexerActive && d->mBalooListener.canHandleRootPaths() && currentConfiguration->forceUsageOfFastFileSearch()) {
+        configurationHasChanged = true;
+    }
+#endif
+
+    auto inputRootPath = currentConfiguration->rootPath();
+    configurationHasChanged = configurationHasChanged || (d->mPreviousRootPathValue != inputRootPath);
+
+    if (configurationHasChanged) {
+        d->mPreviousRootPathValue = inputRootPath;
+    } else {
+        qCDebug(orgKdeElisaIndexersManager()) << "music paths configuration and scanning has not changed";
+        return;
+    }
+
     //resolve symlinks
     QStringList allRootPaths;
-    for (const auto &onePath : currentConfiguration->rootPath()) {
+    for (const auto &onePath : inputRootPath) {
         auto workPath = onePath;
         if (workPath.startsWith(QLatin1String("file:/"))) {
             auto urlPath = QUrl{workPath};
@@ -360,11 +378,31 @@ void MusicListenersManager::configChanged()
     if (!d->mBalooIndexerActive && !d->mFileSystemIndexerActive) {
         testBalooIndexerAvailability();
     }
+
+#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+    if (d->mBalooIndexerAvailable && !d->mBalooIndexerActive && d->mBalooListener.canHandleRootPaths() && currentConfiguration->forceUsageOfFastFileSearch()) {
+        qCDebug(orgKdeElisaIndexersManager()) << "trigger start of baloo file indexer";
+        QMetaObject::invokeMethod(d->mFileListener.fileListing(), "stop", Qt::BlockingQueuedConnection);
+        d->mFileSystemIndexerActive = false;
+        startBalooIndexing();
+    } else if ((!d->mFileSystemIndexerActive && d->mBalooIndexerActive && !d->mBalooListener.canHandleRootPaths()) ||
+               !currentConfiguration->forceUsageOfFastFileSearch()) {
+        if (d->mBalooIndexerActive) {
+            qCDebug(orgKdeElisaIndexersManager()) << "trigger stop of baloo file indexer";
+            QMetaObject::invokeMethod(d->mBalooListener.fileListing(), "stop", Qt::BlockingQueuedConnection);
+        }
+        d->mBalooIndexerActive = false;
+        startLocalFileSystemIndexing();
+    }
+#endif
+
     if (d->mBalooIndexerActive) {
+        qCInfo(orgKdeElisaIndexersManager()) << "trigger init of baloo file indexer";
 #if defined KF5Baloo_FOUND && KF5Baloo_FOUND
         QMetaObject::invokeMethod(d->mBalooListener.fileListing(), "init", Qt::QueuedConnection);
 #endif
     } else if (d->mFileSystemIndexerActive) {
+        qCInfo(orgKdeElisaIndexersManager()) << "trigger init of local file indexer";
         QMetaObject::invokeMethod(d->mFileListener.fileListing(), "init", Qt::QueuedConnection);
     }
 
@@ -386,8 +424,6 @@ void MusicListenersManager::configChanged()
                 this, &MusicListenersManager::monitorStartingListeners);
         connect(d->mAndroidMusicListener.get(), &AndroidMusicListener::indexingFinished,
                 this, &MusicListenersManager::monitorEndingListeners);
-        connect(d->mAndroidMusicListener.get(), &AndroidMusicListener::clearDatabase,
-                &d->mDatabaseInterface, &DatabaseInterface::removeAllTracksFromSource);
     }
 #endif
 }
@@ -428,10 +464,22 @@ void MusicListenersManager::cleanedDatabase()
 void MusicListenersManager::balooAvailabilityChanged()
 {
 #if defined KF5Baloo_FOUND && KF5Baloo_FOUND
-    if (!d->mBalooDetector.balooAvailability()) {
+    if (!d->mBalooDetector.balooAvailability() || !d->mBalooListener.canHandleRootPaths()) {
+        if (d->mBalooDetector.balooAvailability()) {
+            qCInfo(orgKdeElisaIndexersManager) << "Baloo indexer is available";
+            d->mBalooIndexerAvailable = true;
+        }
 #else
     if (true) {
 #endif
+
+#if defined KF5Baloo_FOUND && KF5Baloo_FOUND
+        if (!d->mBalooListener.canHandleRootPaths() && d->mBalooDetector.balooAvailability())
+        {
+            qCInfo(orgKdeElisaIndexersManager()) << "Baloo cannot handle all configured paths: falling back to plain filex indexer";
+        }
+#endif
+
         if (!d->mFileSystemIndexerActive) {
             startLocalFileSystemIndexing();
         }
