@@ -21,10 +21,10 @@
 #include "databaseinterface.h"
 #include "datatypes.h"
 #include "filescanner.h"
+#include "filewriter.h"
 
 #include <QSet>
 #include <QList>
-#include <QDebug>
 
 #include <array>
 #include <algorithm>
@@ -45,6 +45,7 @@ public:
 
     FileScanner mFileScanner;
 
+    FileWriter mFileWriter;
 };
 
 TracksListener::TracksListener(DatabaseInterface *database, QObject *parent) : QObject(parent), d(std::make_unique<TracksListenerPrivate>())
@@ -229,9 +230,11 @@ void TracksListener::newEntryInList(qulonglong newDatabaseId,
     case ElisaUtils::Album:
         newAlbumInList(newDatabaseId, entryTitle);
         break;
+    case ElisaUtils::Genre:
+        newGenreInList(newDatabaseId, entryTitle);
+        break;
     case ElisaUtils::Lyricist:
     case ElisaUtils::Composer:
-    case ElisaUtils::Genre:
     case ElisaUtils::Unknown:
         break;
     }
@@ -301,4 +304,24 @@ void TracksListener::newArtistInList(qulonglong newDatabaseId, const QString &ar
     Q_EMIT tracksListAdded(newDatabaseId, artist, ElisaUtils::Artist, newTracks);
 }
 
+void TracksListener::newGenreInList(qulonglong newDatabaseId, const QString &entryTitle)
+{
+    auto newTracks = d->mDatabase->tracksDataFromGenre(entryTitle);
+
+    if (newTracks.isEmpty()) {
+        return;
+    }
+
+    for (const auto &oneTrack : newTracks) {
+        d->mTracksByIdSet.insert(oneTrack.databaseId());
+    }
+
+    Q_EMIT tracksListAdded(newDatabaseId, entryTitle, ElisaUtils::Genre, newTracks);
+}
+
+void TracksListener::updateSingleFileMetaData(const QUrl &url, DataTypes::ColumnsRoles role, QVariant data)
+{
+    d->mFileWriter.writeSingleMetaDataToFile(url, role, data);
+}
+
 #include "moc_trackslistener.cpp"
